@@ -8,6 +8,14 @@ pub struct PromptArgs {
     pub vi_mode: String,
 }
 
+#[derive(Debug, Args)]
+pub struct RightPromptArgs {
+    #[clap(long)]
+    pub last_duration: u64,
+    #[clap(long)]
+    pub last_command: String,
+}
+
 #[derive(Debug, Args)]
 pub struct InitArgs {}
 
@@ -18,6 +26,7 @@ pub enum Cmds {
     Init(InitArgs),
     #[clap(about = "Print the prompt")]
     Prompt(PromptArgs),
+    RightPrompt(RightPromptArgs),
 }
 
 #[derive(Debug, Parser)]
